# BH1750FVI

Rohm Light Sensor

- Device addresses: 35, 92
- Address type 7-bit

### Addr 0 0-bytes Write-only | # Power Down ## No active state |
### Addr 1 0-bytes Write-only | # Power On ## Waiting for measurement command |
### Addr 7 0-bytes Write-only | # Reset ## Reset data register value. Not accepted in Power Down mode. |
### Addr 16 0-bytes Write-only | # Continuously H-Resolution Mode ## Start measurement at 1lx resolution. Typically 120ms. |
### Addr 17 0-bytes Write-only | # Continously H-Resolution Mode2 ## Start measurement at 0.5lx resolution. Typically 120ms. |
### Addr 19 0-bytes Write-only | # Continuously L-Resolution Mode ## Start measurement at 4lx resolution. Typically 16ms. |
### Addr 32 0-bytes Write-only | # One Time H-Resolution Mode ## Start measurement at 1lx resolution. Typically 120ms. Power Down after measurement. |
### Addr 33 0-bytes Write-only | # One Time H-Resolution Mode2 ## Start measurement at 0.5lx resolution. Typically 120ms. Power Down after measurement. |
### Addr 35 0-bytes Write-only | # One Time L-Resolution Mode ## Start measurement at 4lx resolution. Typically 16ms. Power Down after measurement. |

## Functions

- _lifecycle.Begin - Sends a POWER ON cmd to device
- command.PowerDown - Things you can do to device
- command.Reset - Things you can do to device
- read.LightIntensity - Read light intensity from device